
"""
Auto-generated URL configuration for zone: public
Generated by Django Revolution
"""
from django.urls import path, include

# Zone-specific URL patterns for public
urlpatterns = [
    path("api/public_api/", include("django_sample.apps.public_api.urls")),
]
