
"""
Auto-generated URL configuration for zone: encar_public
Generated by Django Revolution
"""
from django.urls import path, include

# Zone-specific URL patterns for encar_public
urlpatterns = [
    path("apix/data_encar_api/", include("src.data_encar_api.urls")),
]
