
"""
Auto-generated URL configuration for zone: client
Generated by Django Revolution
"""
from django.urls import path, include

# Zone-specific URL patterns for client
urlpatterns = [
    path("apix/accounts/", include("src.accounts.urls")),
    path("apix/billing/", include("src.billing.urls")),
    path("apix/payments/", include("src.payments.urls")),
    path("apix/support/", include("src.support.urls")),
    path("apix/public/", include("src.public.urls")),
]
