
"""
Auto-generated URL configuration for zone: internal
Generated by Django Revolution
"""
from django.urls import path, include

# Zone-specific URL patterns for internal
urlpatterns = [
    path("apix/system/", include("src.system.urls")),
    path("apix/mailer/", include("src.mailer.urls")),
]
