
"""
Auto-generated URL configuration for zone: private
Generated by Django Revolution
"""
from django.urls import path, include

# Zone-specific URL patterns for private
urlpatterns = [
    path("api/private_api/", include("django_sample.apps.private_api.urls")),
]
