
"""
Auto-generated URL configuration for zone: admin
Generated by Django Revolution
"""
from django.urls import path, include

# Zone-specific URL patterns for admin
urlpatterns = [
    path("apix/services/", include("src.services.urls")),
]
